@@ -3,7 +3,7 @@ package App::ZodiacUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-01-01'; # DATE
 our $DIST = 'App-ZodiacUtils'; # DIST
-our $VERSION = '0.111'; # VERSION
+our $VERSION = '0.112'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,7 +14,7 @@ our %SPEC;
 my $sch_array_of_dates = ['array*', {
     of=>['date*', {
         'x.perl.coerce_to' => 'DateTime',
-        'x.perl.coerce_rules'=>['From_str::natural'],
+        'x.perl.coerce_rules'=>['From_str::alami_en'],
     }],
     min_len=>1,
 }];
@@ -141,7 +141,7 @@ App::ZodiacUtils - CLI utilities related to zodiac
 
 =head1 VERSION
 
-This document describes version 0.111 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2020-01-01.
+This document describes version 0.112 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2020-01-01.
 
 =head1 DESCRIPTION
 
